@@ -13,7 +13,7 @@ def main():
     parser.add_argument('--password', type=str, dest='password', help='Password', required=True)
     parser.add_argument('--url', type=str, dest='url', help='Sharepoint server URL', required=True)
     parser.add_argument('--list', type=str, dest='list', help='Name or ID of list', required=True)
-    parser.add_argument('--cmd',  type=str, dest='cmd', help='command: fields|items', required=True)
+    parser.add_argument('--cmd', type=str, dest='cmd', help='command: fields|items', required=True)
 
     args = parser.parse_args()
     service = connector.Connector(args.url,
@@ -25,8 +25,9 @@ def main():
     if cmd == 'fields':
         fields = service.model
         print 'Primary key: %s' % service.primary_key
-        for name in sorted(service.required_fields):
-            print 'Required field: %s' % name
+        print 'Required fields:'
+        pprint.pprint(sorted(service.required_fields)
+        print 'All fields:'
         for field in sorted(service.all_fields):
             pprint.pprint(service.model[field])
 
